%define url_ver	%(echo %{version}|sed 's/[.]/./g')

Name:		chessx
Version:	1.6.0
Release:	%mkrel 1
Summary:	An Open Source chess database
License:	GPLv2
Group:		Games/Boards
URL:		https://chessx.sourceforge.io/
Source0:	https://sourceforge.net/projects/chessx/files/%{name}/%{version}/%{name}-%{url_ver}.tgz
# upstream patches
# https://github.com/Isarhamster/chessx/pull/61
Patch002:	0002-Fix-install-path-of-icons-on-Linux.patch
# https://github.com/Isarhamster/chessx/pull/63
Patch003:	0003-Allow-linking-against-system-libraries-via-pkg-confi.patch
# mageia patches
Patch10:	chessx-mga-install-lang-and-data-files.patch

BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Multimedia)
BuildRequires:	cmake(Qt6MultimediaWidgets)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6PrintSupport)
BuildRequires:	cmake(Qt6Svg)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6TextToSpeech)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	pkgconfig(quazip1-qt6)

# Bundles part of scid 1.0 (https://sourceforge.net/projects/scid/)
Provides:	bundled(scid) = 1.0

%description
ChessX is an Open Source chess database. With ChessX you can operate on your
collection of chess games in many ways:
browse, edit, add, organize, analyze, etc.

%prep
%autosetup -p1

# Ensure bundled quazip code is not used
#rm -rf src/quazip

%build
%{_qt6_bindir}/lrelease i18n/*.ts
%qmake_qt6 -r CONFIG+=link_pkgconfig CONFIG+=speech
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

%files
%license COPYING.md
%doc README.md ChangeLog.md
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_metainfodir}/io.sourceforge.ChessX.metainfo.xml


%changelog
* Thu May 16 2024 daviddavid <daviddavid> 1.6.0-1.mga10
+ Revision: 2064419
- new version: 1.6.0
- switch to Qt6

* Sat Sep 02 2023 daviddavid <daviddavid> 1.5.8-3.mga10
+ Revision: 1983564
- rebuild for new quazip 1.4

* Tue Mar 28 2023 daviddavid <daviddavid> 1.5.8-2.mga9
+ Revision: 1950542
- don't know why but since chessx compiled with cmake it seems to crash randomly
  so let's build it again against qmake (currently main upstream developed)

* Thu Feb 02 2023 daviddavid <daviddavid> 1.5.8-1.mga9
+ Revision: 1937642
- new version: 1.5.8
- switch to cmake build system
- add patch to use system quazip
- package upstream metainfo file

* Sun Sep 11 2022 neoclust <neoclust> 1.5.6-1.mga9
+ Revision: 1886878
- New version 	1.5.6

* Wed Apr 06 2022 umeabot <umeabot> 1.5.4-3.mga9
+ Revision: 1845812
- Mageia 9 Mass Rebuild

* Wed Dec 16 2020 umeabot <umeabot> 1.5.4-2.mga8
+ Revision: 1658220
- Rebuild for new Qt5

* Tue Jul 14 2020 daviddavid <daviddavid> 1.5.4-1.mga8
+ Revision: 1606017
- new version: 1.5.4
- update Url
- remove merged upstream patch
+ danf <danf>
- Switch URLs from http: to https:

* Sat Feb 15 2020 umeabot <umeabot> 1.4.6-5.mga8
+ Revision: 1524415
- Mageia 8 Mass Rebuild

* Sat Mar 30 2019 umeabot <umeabot> 1.4.6-4.mga7
+ Revision: 1381434
- Qt5 Rebuild

* Sat Sep 22 2018 umeabot <umeabot> 1.4.6-3.mga7
+ Revision: 1296118
- Mageia 7 Mass Rebuild

* Mon Jun 04 2018 daviddavid <daviddavid> 1.4.6-2.mga7
+ Revision: 1234415
- add patch to fix build with new Qt5 >= 5.11.0

* Sat Jul 01 2017 daviddavid <daviddavid> 1.4.6-1.mga6
+ Revision: 1108853
- new version: 1.4.6

* Tue Mar 22 2016 daviddavid <daviddavid> 1.4.0-1.mga6
+ Revision: 993896
- new version: 1.4.0
- remove merged upstream patches

* Fri Jan 22 2016 daviddavid <daviddavid> 1.3.2-3.mga6
+ Revision: 926541
- add patch1 to fix build with gcc 5.3.1
  * https://sourceforge.net/p/chessx/bugs/229/
- split out all Qt5 BuildRequires

* Mon Aug 10 2015 daviddavid <daviddavid> 1.3.2-2.mga6
+ Revision: 862351
- add patch0 to fix build with Qt 5.5
  * http://sourceforge.net/p/chessx/bugs/227/

* Sat Jun 20 2015 daviddavid <daviddavid> 1.3.2-1.mga6
+ Revision: 835883
- add missing BuildRequires on Qt5Multimedia
- new version: 1.3.2

* Sun Oct 19 2014 daviddavid <daviddavid> 1.2.2-1.mga5
+ Revision: 791779
- new version: 1.2.2
- switch to Qt5 build
- update BRs for Qt5 build

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0-5.mga5
+ Revision: 739180
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0-4.mga5
+ Revision: 678374
- Mageia 5 Mass Rebuild

* Mon Aug 11 2014 daviddavid <daviddavid> 1.2.0-3.mga5
+ Revision: 661801
- bump release

* Mon Aug 11 2014 daviddavid <daviddavid> 1.2.0-2.mga5
+ Revision: 661794
- fix an issue with the compilation of available languages
  * we need to compile all languages files before %%make

* Mon Aug 04 2014 daviddavid <daviddavid> 1.2.0-1.mga5
+ Revision: 659689
- update url_version of Source0 (now uses '.' rather than '-')
- remove the previous fix of desktop file as it is now fixed upstream
- fix for correct assignment of rights of all the circle_*.svg files
- new version: 1.2.0

* Tue Mar 18 2014 david-david <david-david> 1.1.0-1.mga5
+ Revision: 605146
- fix upstream desktop file on missing semicolon (';')
- update linkurl Source0
- add more icons
- use desktop file provides on tarball
- new version: 1.1.0

* Fri Feb 14 2014 dams <dams> 1.0.0-1.mga5
+ Revision: 591447
- new version 1.0.0

* Fri Oct 18 2013 umeabot <umeabot> 0.9.4-4.mga4
+ Revision: 503319
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0.9.4-3.mga3
+ Revision: 347673
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 dams <dams> 0.9.4-2.mga3
+ Revision: 332984
- add back icon (broken by last update)

* Mon Dec 17 2012 kamil <kamil> 0.9.4-1.mga3
+ Revision: 332147
- new version 0.9.4

* Sat Dec 01 2012 kamil <kamil> 0.9.2-2.mga3
+ Revision: 324365
- clean a bit .spec

* Fri Nov 16 2012 dams <dams> 0.9.2-1.mga3
+ Revision: 318925
- new version 0.9.2
- update buildrequire
- now use project icon instead of generic icon
- update specfile to enable i18n translations

* Mon Sep 19 2011 obgr_seneca <obgr_seneca> 0.8-1.mga2
+ Revision: 145389
- imported package chessx


* Sun Sep 18 2011 Kamil Rytarowski <n54@gmx.com> 0.8-1
- initial package for Mageia
- thanks to some guys at pacman for the inspiration taken from their spec file
